@@ -4,7 +4,7 @@ use base 'Class::Accessor::Fast';
 use strict;
 use warnings;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use Carp qw( carp croak );
 use URI;
@@ -31,7 +31,7 @@ Net::FreshBooks::API - Easy OO access to the FreshBooks.com API
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =head1 SYNOPSIS
 
@@ -155,8 +155,241 @@ Repository: L<http://github.com/oalders/net-freshbooks-api/tree/master>
 
 Create a new API object.
 
+=head2 client
+
+This returns a Net::FreshBooks::API::Client object.  The following methods are
+available, as documented in the FreshBooks API:
+
+=head3 client->create
+
+    # create a new client
+    my $client = $fb->client->create(
+        {   first_name   => 'Larry',
+            last_name    => 'Wall',
+            organization => 'Perl HQ',
+            email        => 'larry@example.com',
+        }
+    );
+
+Once you have a client object, you may set any of the mutable fields by
+calling the appropriate method on the object:
+
+    $client->first_name( 'Lawrence' );
+    $client->last_name( 'Wahl' );
+
+These changes will not be reflected in your FreshBooks account until you call
+the update() method, which is described below.
+
+=head3 client->update
+
+    # take the client object created above
+    # we can now make changes to the client and save them
+    $client->organization('Perl Foundation');
+    $client->update;
+
+    # or more quickly
+    $client->update( { organization => 'Perl Foundation', } );
+
+=head3 client->get
+
+    # or, fetch a client based on its FreshBooks client_id
+    my $client = $fb->client->get({ client_id => $client_id });
+
+=head3 client->delete
+
+    # fetch a client and then delete it
+    my $client = $fb->client->get({ client_id => $client_id });
+    $client->delete;
+
+=head3 client->list
+
+    # or, list all active clients
+    my $clients = $fb->client->list();
+
+    while ( my $client = $clients->next ) {
+        print join( "\t", $client->client_id, $client->first_name, $client->last_name ) . "\n";
+    }
+
+
+=head2 invoice
+
+Create a new L<Net::FreshBooks::API::Invoice> object.
+
+=head3 invoice->create
+
+Create an invoice in the FreshBooks system.
+
+my $invoice = $fb->invoice->create({...});
+
+=head3 invoice->add_line
+
+Create a new L<Net::FreshBooks::API::InvoiceLine> object and add it to the end
+of the list of lines
+
+    my $bool = $invoice->add_line(
+        {   name         => "Yard Work",          # (Optional)
+            description  => "Mowed the lawn.",    # (Optional)
+            unit_cost    => 10,                   # Default is 0
+            quantity     => 4,                    # Default is 0
+            tax1_name    => "GST",                # (Optional)
+            tax2_name    => "PST",                # (Optional)
+            tax1_percent => 8,                    # (Optional)
+            tax2_percent => 6,                    # (Optional)
+        }
+    );
+
+
+=head3 invoice->send_by_email
+
+Send the invoice by email.
+
+  my $result = $invoice->send_by_email();
+
+=head3 invoice->send_by_snail_mail
+
+Send the invoice by snail mail.
+
+  my $result = $invoice->send_by_snail_mail();
+
+=head3 invoice->update
+
+Please see client->update for an example of how to use this method.
+
+=head3 invoice->get
+
+    my $invoice = $fb->invoice->get({ invoice_id => $invoice_id });
+
+=head3 invoice->delete
+
+    my $invoice = $fb->invoice->get({ invoice_id => $invoice_id });
+    $invoice->delete;
+
+=head3 invoice->list
+
+    my $invoices = $fb->invoice->list;
+    while ( my $invoice = $invoices->list ) {
+        print $invoice->invoice_id, "\n";
+    }
+
+=head2 payment
+
+Create a new L<Net::FreshBooks::API::Payment> object.
+
+=head3 payment->create
+
+Create a new payment in the FreshBooks system
+
+    my $payment = $fb->payment->create({...});
+
+=head3 payment->update
+
+Please see client->update for an example of how to use this method.
+
+=head3 payment->get
+
+    my $payment = $fb->payment->get({ payment_id => $payment_id });
+
+=head3 payment->delete
+
+    my $payment = $fb->payment->get({ payment_id => $payment_id });
+    $payment->delete;
+
+=head3 payment->list
+
+    my $payments = $fb->payment->list;
+    while ( my $payment = $payments->list ) {
+        print $payment->payment_id, "\n";
+    }
+
+=head2 recurring
+
+Create a new L<Net::FreshBooks::API::Recurring> object.
+
+=head3 recurring->create
+
+    my $recurring = $fb->recurring->create({...});
+
+=head3 recurring->update
+
+Please see client->update for an example of how to use this method.
+
+=head3 recurring->get
+
+    my $item = $recurring->get({ recurring_id => $recurring_id });
+
+=head3 recurring->delete
+
+    my $item = $recurring->get({ recurring_id => $recurring_id });
+    $item->delete;
+
+=head3 recurring->list
+
+    my $recurrings = $fb->recurring->list;
+    while ( my $recurring = $recurrings->list ) {
+        print $recurring->recurring_id, "\n";
+    }
+
+
+=head2 ping
+
+  my $bool = $fb->ping(  );
+
+Ping the server with a trivial request to see if a connection can be made.
+Returns true if the server is reachable and the authentication details are
+valid.
+
+=head2 service_url
+
+  my $url = $fb->service_url(  );
+
+Returns a L<URI> object that represents the service URL.
+
+=head2 ua
+
+  my $ua = $fb->ua;
+
+Return a LWP::UserAgent object to use when contacting the server.
+
+=head2 delete_everything_from_this_test_account
+
+    my $deletion_count
+        = $fb->delete_everything_from_this_test_account();
+
+Deletes all clients, invoices and payments from this account. This is convenient
+when testing but potentially very dangerous. To prevent accidential deletions
+this method has a very long name, and will croak if the account name does not
+end with 'test'.
+
+As a general rule it is best to put this at the B<start> of your test scripts
+rather than at the end. This will let you inspect your account at the end of the
+test script to see what is left behind.
+
+=head1 AUTHOR
+
+Edmund von der Burg C<<evdb@ecclestoad.co.uk>>
+
+Developed for HinuHinu L<http://www.hinuhinu.com/>.
+
+Recurring item support by:
+
+Olaf Alders olaf@raybec.com
+
+Developed for Raybec Communications L<http://www.raybec.com>
+
+=head1 LICENCE
+
+Perl
+
+=head1 SEE ALSO
+
+L<WWW::FreshBooks::API> - an alternative interface to FreshBooks.
+
+L<http://developers.freshbooks.com/overview/> the FreshBooks API documentation.
+
 =cut
 
+
+
 sub new {
     my $class = shift;
     my $args  = shift;
@@ -185,8 +418,8 @@ sub new {
         if ( ref $args->{communication_log} ne 'CODE' ) {
             my $file = file( $args->{communication_log} )->absolute;
             $args->{communication_log} = sub {
-                my ($message) = @_;
-                my $fh = $file->open('a')
+                my ( $message ) = @_;
+                my $fh = $file->open( 'a' )
                     || croak "Could not open for append: $file";
                 $fh->print(
                     $message->as_string . "\n\n" . '-' x 80 . "\n\n" );
@@ -200,25 +433,18 @@ sub new {
     return bless {%$args}, $class;
 }
 
+
 sub _log {    ## no critic
     my $self = shift;
-    return $self->verbose->(@_);
+    return $self->verbose->( @_ );
 }
 
+
 sub _clog {    ## no critic
     my $self = shift;
-    return $self->communication_log->(@_);
+    return $self->communication_log->( @_ );
 }
 
-=head2 ping
-
-  my $bool = $fb->ping(  );
-
-Ping the server with a trivial request to see if a connection can be made.
-Returns true if the server is reachable and the authentication details are
-valid.
-
-=cut
 
 sub ping {
     my $self = shift;
@@ -229,13 +455,6 @@ sub ping {
     return 1;
 }
 
-=head2 service_url
-
-  my $url = $fb->service_url(  );
-
-Returns a L<URI> object that represents the service URL.
-
-=cut
 
 sub service_url {
     my $self = shift;
@@ -250,13 +469,6 @@ sub service_url {
     return $uri;
 }
 
-=head2 client, invoice, payment, recurring
-
-  my $client = $fb->client->create({...});
-
-Accessor to the various objects in the API.
-
-=cut
 
 sub client {
     my $self = shift;
@@ -264,31 +476,27 @@ sub client {
     return Net::FreshBooks::API::Client->new( { _fb => $self, %$args } );
 }
 
+
 sub invoice {
     my $self = shift;
     my $args = shift || {};
     return Net::FreshBooks::API::Invoice->new( { _fb => $self, %$args } );
 }
 
+
 sub payment {
     my $self = shift;
     my $args = shift || {};
     return Net::FreshBooks::API::Payment->new( { _fb => $self, %$args } );
 }
 
+
 sub recurring {
     my $self = shift;
     my $args = shift || {};
     return Net::FreshBooks::API::Recurring->new( { _fb => $self, %$args } );
 }
 
-=head2 ua
-
-  my $ua = $fb->ua;
-
-Return a LWP::UserAgent object to use when contacting the server.
-
-=cut
 
 my $CACHED_UA = undef;
 
@@ -296,7 +504,7 @@ sub ua {
     my $self = shift;
     return $CACHED_UA if $CACHED_UA;
 
-    my $class = ref($self) || $self;
+    my $class = ref( $self ) || $self;
     my $version = $VERSION;
 
     my $ua = LWP::UserAgent->new(
@@ -322,23 +530,9 @@ sub ua {
     return $CACHED_UA = $ua;
 }
 
-=head2 delete_everything_from_this_test_account
-
-    my $deletion_count
-        = $fb->delete_everything_from_this_test_account();
-
-Deletes all clients, invoices and payments from this account. This is convenient
-when testing but potentially very dangerous. To prevent accidential deletions
-this method has a very long name, and will croak if the account name does not
-end with 'test'.
-
-As a general rule it is best to put this at the B<start> of your test scripts
-rather than at the end. This will let you inspect your account at the end of the
-test script to see what is left behind.
-
-=cut
 
 sub delete_everything_from_this_test_account {
+
     my $self = shift;
 
     my $name = $self->account_name;
@@ -353,7 +547,7 @@ sub delete_everything_from_this_test_account {
     my @names_to_delete = qw( invoice client );
 
     # clear out all existing clients etc on this account.
-    foreach my $object_name (@names_to_delete) {
+    foreach my $object_name ( @names_to_delete ) {
         my $objects_to_delete = $self->$object_name->list();
         while ( my $obj = $objects_to_delete->next ) {
             $obj->delete;
@@ -364,28 +558,5 @@ sub delete_everything_from_this_test_account {
     return $delete_count;
 }
 
-=head1 AUTHOR
-
-Edmund von der Burg C<<evdb@ecclestoad.co.uk>>
-
-Developed for HinuHinu L<http://www.hinuhinu.com/>.
-
-Recurring item support by:
-
-Olaf Alders olaf@raybec.com
-
-Developed for Raybec Communications L<http://www.raybec.com>
-
-=head1 LICENCE
-
-Perl
-
-=head1 SEE ALSO
-
-L<WWW::FreshBooks::API> - an alternative interface to FreshBooks.
-
-L<http://developers.freshbooks.com/overview/> the FreshBooks API documentation.
-
-=cut
 
 1;
